﻿// <copyright file="frmGetPending.cs" company="Microsoft Corporation"> Copyright © Microsoft Corporation. All Rights Reserved. This code released under the terms of the Microsoft Public License (MS-PL, http://opensource.org/licenses/ms-pl.html.) This is sample code only, do not use in production environments</copyright>

// Visual Studio ALM Ranger Sample Source Code
//
// Project Name: ALMRangersGetPending
// File Name: frmGetPending.cs
//
// Description: Sample code to demonstrate some of the APIs of the Team Foundation
//              Server Object Model. This sample demsontrates connecting to a server, 
//              using the local registered servers, using the version control service
//              to get a list of projects, creating workspaces, adding files to
//              workspace, and checking them in as another user. There is no or 
//              minimal error handling in the sample.
//
// Author(s): Brian Blacklman
//
// This is sample code for demonstration purposes only and therefore the intent is to
// demonstrate key features and may not contain coding best practices. 
// Put this code through your own quality standards and testing process before using 
// this code in production systems.
namespace GetPendingChanges
{
    using System;
    using System.Net;
    using System.Windows.Forms;
    using Microsoft.TeamFoundation.Client;
    using Microsoft.TeamFoundation.VersionControl.Client;

    public partial class Form1 : Form
    {
        public Form1()
        {
            this.InitializeComponent();
        }

       private void btnConnect_Click(object sender, EventArgs e)
        {
  

            // Connect to the team project collection and the server that hosts the version-control repository. 
            using (TfsTeamProjectCollection tpc = new TfsTeamProjectCollection(new Uri(this.txtTFS.Text), new UICredentialsProvider()))
            {
                VersionControlServer vcServer = tpc.GetService<VersionControlServer>();

                ItemSpec[] itemSpecs = new ItemSpec[1];

                // You can filter the path to a project and folder using $/ProjectName/Folder...
                itemSpecs[0] = new ItemSpec(@"$/Tailspin Toys/Development/Iteration 2", RecursionType.Full);

                // Your options for filtering are the Workspace Name, User Name, and the above path in
                // the itemspec.
                const string QryWSName = "WIN-GS9GMUJITS8";
                const string QryUserName = "administrator";
                const bool IncludeDownloadInfo = true;

                PendingSet[] pendingSet = vcServer.QueryPendingSets(itemSpecs, QryWSName, QryUserName, IncludeDownloadInfo);

                foreach (PendingSet ps in pendingSet)
                {
                    this.lbPendingChanges.Items.Add(ps.ToString());
                }
            }
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
