﻿// <copyright file="frmTFSConnections.cs" company="Microsoft Corporation"> Copyright © Microsoft Corporation. All Rights Reserved. This code released under the terms of the Microsoft Public License (MS-PL, http://opensource.org/licenses/ms-pl.html.) This is sample code only, do not use in production environments</copyright>

// Visual Studio ALM Ranger Sample Source Code
//
// Project Name: ALMRangersTFsConnections
// File Name: frmTFSConnections.cs
//
// Description: Sample code to demonstrate some of the APIs of the Team Foundation
//              Server Object Model. This sample demsontrates connecting to a server,
//              list all collections, and all projects for selected collection.
//              There is no or minimal error handling in the sample.
//
// Author(s): Brian Blacklman
//
// This is sample code for demonstration purposes only and therefore the intent is to
// demonstrate key features and may not contain coding best practices. 
// Put this code through your own quality standards and testing process before using 
// this code in production systems.
namespace TFSConnections
{
    using System;
    using System.Collections.ObjectModel;
    using System.Net;
    using System.Windows.Forms;
    using Microsoft.TeamFoundation.Client;
    using Microsoft.TeamFoundation.Framework.Client;
    using Microsoft.TeamFoundation.Framework.Common;
    
    public partial class frmTFSConnections : Form
    {
        // Form level variable to store the URI for the Team Foundation Server
        private Uri tfsUri;

        // Read only collection container of collection as there will be no writing
        private ReadOnlyCollection<CatalogNode> collectionNodes;

        public frmTFSConnections()
        {
            this.InitializeComponent();
        }

        private void VerifyTfsServer(object sender, EventArgs e)
        {

            this.tfsUri = new Uri(this.txtBoxUri.Text);

            using (TfsConfigurationServer configurationServer = new TfsConfigurationServer(this.tfsUri, new UICredentialsProvider()))
            {
                // Get the catalog of team project collections
                this.collectionNodes = configurationServer.CatalogNode.QueryChildren(new[] { CatalogResourceTypes.ProjectCollection }, false, CatalogQueryOptions.None);

                // Clear the list box in case we are called again.
                this.cbTPC.Items.Clear();

                // Loop enumerate the container adding collections to the combo box.
                foreach (CatalogNode collectionNode in this.collectionNodes)
                {
                    this.cbTPC.Items.Add(collectionNode.Resource.DisplayName);
                }
            }
        }

        private void cbTPC_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Clear list box before populating
            this.lbProjects.Items.Clear();

            // Retrieve the index of the selected collection
            ComboBox cb = (ComboBox)sender;
            int index = cb.SelectedIndex;

            // Get a catalog of team projects for the collection
            ReadOnlyCollection<CatalogNode> projectNodes = this.collectionNodes[index].QueryChildren(new[] { CatalogResourceTypes.TeamProject }, false, CatalogQueryOptions.None);

            // Enumerate the team projects in the collection and add to list box
            foreach (CatalogNode projectNode in projectNodes)
            {
                this.lbProjects.Items.Add(projectNode.Resource.DisplayName);
            }
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void txtBoxUri_KeyDown(object sender, KeyEventArgs e)
        {
            // If the user tabs out of the control VerifyTfsServer fires
            // if they press Enter this code gets called.
            if (e.KeyCode == Keys.Enter)
            {
                this.VerifyTfsServer(sender, e);
            }
        }
    }
}
