﻿// <copyright file="frmGetAll.cs" company="Microsoft Corporation"> Copyright © Microsoft Corporation. All Rights Reserved. This code released under the terms of the Microsoft Public License (MS-PL, http://opensource.org/licenses/ms-pl.html.) This is sample code only, do not use in production environments</copyright>

// Visual Studio ALM Ranger Sample Source Code
//
// Project Name: ALMRangersGetAll
// File Name: frmGetAll.cs
//
// Description: Sample code to demonstrate some of the APIs of the Team Foundation
//              Server Object Model. This sample demsontrates connecting to a server
//              directly to the collection when it is known. There is no or minimal
//              error handling in the sample so if the collection is not valid or
//              offline this would fail.
//
// Author(s): Brian Blacklman
//
// This is sample code for demonstration purposes only and therefore the intent is to
// demonstrate key features and may not contain coding best practices. 
// Put this code through your own quality standards and testing process before using 
// this code in production systems.
namespace GetAllFilesFolders
{
    using System;
    using System.Net;
    using System.Windows.Forms;
    using Microsoft.TeamFoundation.Client;
    using Microsoft.TeamFoundation.VersionControl.Client;

    public partial class Form1 : Form
    {
        public Form1()
        {
            this.InitializeComponent();
        }

        private void btnGetAll_Click(object sender, EventArgs e)
        {
            Uri uriTFS = new Uri(txtTFSUri.Text);

            // Connect to the team project collection and the server that hosts the version-control repository. 
            using (TfsTeamProjectCollection tpc = new TfsTeamProjectCollection(uriTFS, new UICredentialsProvider()))
            {
                VersionControlServer vcServer = tpc.GetService<VersionControlServer>();

                // Get a list all of the .xaml files, enumerate them and add to the listbox.
                ItemSet items = vcServer.GetItems("$/*.xaml", RecursionType.Full);
                foreach (Item item in items.Items)
                {
                    this.lbAll.Items.Add(item.ToString());
                }
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void lbAll_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Just making the contents readable.
            this.txtDetails.Text = this.lbAll.Text;
        }
    }
}
